ScriptRunnerShellConfig class

Configuration for shell to use for running scripts.

Constructors

ScriptRunnerShellConfig({String? defaultShell, String? windows, String? macos, String? linux})
Create a new shell configuration from given arguments. When no shell is specified for a platform, the default shell is used.
const
ScriptRunnerShellConfig.parse(dynamic obj)
Parses a shell configuration from a YamlMap, Map or String. Other types will throw a ScriptStateError.
factory

Properties

defaultShell → String?
final
hashCode → int
The hash code for this object.
no setterinherited
linux → String?
final
macos → String?
final
os → OS
The current OS of the system, of those supported by RunnableScript
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shell → String
Returns the shell for the current platform. If no overrides are specified in the config, it attempts to find the default shell for the platform.
no setter
shellExecFlag → String
Returns the shell command-line flag to indicate incoming command
no setter
windows → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited